@@ -10,6 +10,7 @@ from py42.services._connection import Connection
 from py42.usercontext import UserContext
 
 warnings.simplefilter("always", DeprecationWarning)
+warnings.simplefilter("always", UserWarning)
 
 
 def from_local_account(host_address, username, password, totp=None):
@@ -59,7 +60,7 @@ def from_jwt_provider(host_address, jwt_provider):
     """
 
     client = SDKClient.from_jwt_provider(host_address, jwt_provider)
-    client.users.get_current()
+    client.usercontext.get_current_tenant_id()
     return client
 
 
