@@ -1,18 +1,20 @@
-from py42.choices import Choices
-from py42.sdk.queries.fileevents.file_event_query import FileEventFilterStringField
+from py42.choices import Choices as _Choices
+from py42.sdk.queries.fileevents.util import (
+    FileEventFilterStringField as _FileEventFilterStringField,
+)
 from py42.sdk.queries.query_filter import QueryFilterBooleanField
 
 
-class Actor(FileEventFilterStringField):
-    """Class that filters events by the cloud service username of the event originator
+class Actor(_FileEventFilterStringField):
+    """V1 filter class that filters events by the cloud service username of the event originator
     (applies to cloud data source events only).
     """
 
     _term = "actor"
 
 
-class DirectoryID(FileEventFilterStringField):
-    """Class that filters events by unique identifier of the cloud drive or folder where the event
+class DirectoryID(_FileEventFilterStringField):
+    """V1 filter class that filters events by unique identifier of the cloud drive or folder where the event
     occurred (applies to cloud data source events only).
     """
 
@@ -20,23 +22,23 @@ class DirectoryID(FileEventFilterStringField):
 
 
 class Shared(QueryFilterBooleanField):
-    """Class that filters events by the shared status of the file at the time the event occurred
+    """V1 filter class that filters events by the shared status of the file at the time the event occurred
     (applies to cloud data source events only).
     """
 
     _term = "shared"
 
 
-class SharedWith(FileEventFilterStringField):
-    """Class that filters events by the list of users who had been granted access to the file at the
+class SharedWith(_FileEventFilterStringField):
+    """V1 filter class that filters events by the list of users who had been granted access to the file at the
     time of the event (applies to cloud data source events only).
     """
 
     _term = "sharedWith"
 
 
-class SharingTypeAdded(FileEventFilterStringField, Choices):
-    """Class that filters results to include events where a file's sharing permissions were
+class SharingTypeAdded(_FileEventFilterStringField, _Choices):
+    """V1 filter class that filters results to include events where a file's sharing permissions were
     changed to a value that increases exposure (applies to cloud data source events only).
 
     Available options provided as class attributes:
